@@ -5,36 +5,39 @@ datazen - A module implementing various data-file decoders.
 # built-in
 from configparser import ConfigParser, Error, ExtendedInterpolation
 import json
-import logging
-from typing import Dict, NamedTuple, TextIO
+from logging import Logger, getLogger
+from time import perf_counter_ns
+from typing import Dict
 
 # third-party
-from ruamel.yaml import YAML, parser, scanner
+from ruamel.yaml import parser, scanner
 
-LOG = logging.getLogger(__name__)
+# internal
+from datazen.code.types import YAML_INTERFACE, DataStream, LoadResult
+
+LOG = getLogger(__name__)
 INI_INTERPOLATION = ExtendedInterpolation()
 
 
-class LoadResult(NamedTuple):
-    """
-    An encapsulation of the result of loading raw data, the data collected and
-    whether or not it succeeded.
-    """
-
-    data: dict
-    success: bool
-
-
 def decode_ini(
-    data_file: TextIO,
-    logger: logging.Logger = LOG,
+    data_file: DataStream,
+    logger: Logger = LOG,
+    **kwargs,
 ) -> LoadResult:
     """Load INI data from a text stream."""
 
+    start = perf_counter_ns()
     data = {}
     loaded = True
 
-    cparser = ConfigParser(interpolation=INI_INTERPOLATION)
+    # Allow interpolation when reading by default.
+    interpolation = kwargs.get("interpolation", INI_INTERPOLATION)
+    try:
+        del kwargs["interpolation"]
+    except KeyError:
+        pass
+
+    cparser = ConfigParser(interpolation=interpolation, **kwargs)
     try:
         cparser.read_file(data_file)
 
@@ -47,40 +50,44 @@ def decode_ini(
         loaded = False
         logger.error("config-load error: %s", exc)
 
-    return LoadResult(data, loaded)
+    return LoadResult(data, loaded, perf_counter_ns() - start)
 
 
 def decode_json(
-    data_file: TextIO,
-    logger: logging.Logger = LOG,
+    data_file: DataStream,
+    logger: Logger = LOG,
+    **kwargs,
 ) -> LoadResult:
     """Load JSON data from a text stream."""
 
+    start = perf_counter_ns()
     data = {}
     loaded = True
     try:
-        data = json.load(data_file)
+        data = json.load(data_file, **kwargs)
         if not data:
             data = {}
     except json.decoder.JSONDecodeError as exc:
         loaded = False
         logger.error("json-load error: %s", exc)
-    return LoadResult(data, loaded)
+    return LoadResult(data, loaded, perf_counter_ns() - start)
 
 
 def decode_yaml(
-    data_file: TextIO,
-    logger: logging.Logger = LOG,
+    data_file: DataStream,
+    logger: Logger = LOG,
+    **kwargs,
 ) -> LoadResult:
     """Load YAML data from a text stream."""
 
+    start = perf_counter_ns()
     data = {}
     loaded = True
     try:
-        data = YAML(typ="safe").load(data_file)
+        data = YAML_INTERFACE.load(data_file, **kwargs)
         if not data:
             data = {}
     except (scanner.ScannerError, parser.ParserError) as exc:
         loaded = False
         logger.error("yaml-load error: %s", exc)
-    return LoadResult(data, loaded)
+    return LoadResult(data, loaded, perf_counter_ns() - start)
