@@ -1,7 +1,7 @@
 # =====================================
 # generator=datazen
-# version=1.9.3
-# hash=7c1f5759e33a30d1976f4000868363c8
+# version=1.12.1
+# hash=c0c8b2f1e5456cb6bd203f0d5591f6d0
 # =====================================
 
 """
@@ -12,6 +12,7 @@ datazen - This package's command-line entry-point (boilerplate).
 import argparse
 import logging
 import os
+from pathlib import Path
 import sys
 from typing import List
 
@@ -46,11 +47,12 @@ def main(argv: List[str] = None) -> int:
     parser.add_argument(
         "-C",
         "--dir",
-        default=os.getcwd(),
+        default=Path.cwd(),
         dest="dir",
+        type=Path,
         help="execute from a specific directory",
     )
-    starting_dir = os.getcwd()
+    starting_dir = Path.cwd()
 
     add_app_args(parser)
 
@@ -58,7 +60,7 @@ def main(argv: List[str] = None) -> int:
     try:
         args = parser.parse_args(command_args[1:])
         args.version = VERSION
-        args.dir = os.path.abspath(args.dir)
+        args.dir = args.dir.resolve()
 
         # initialize logging
         log_level = logging.DEBUG if args.verbose else logging.INFO
